package sun.awt.image;

import java.awt.image.IndexColorModel;
import java.awt.image.DirectColorModel;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import java.awt.image.ColorModel;

public class JPEGImageDecoder extends ImageDecoder
{
    private static ColorModel RGBcolormodel;
    private static ColorModel ARGBcolormodel;
    private static ColorModel Graycolormodel;
    private static final Class InputStreamClass;
    private ColorModel colormodel;
    Hashtable props;
    private static final int hintflags = 22;
    
    private static native void initIDs(Class p0);
    
    private native void readImage(InputStream p0, byte[] p1) throws ImageFormatException, IOException;
    
    public JPEGImageDecoder(InputStreamImageSource inputStreamImageSource, InputStream inputStream) {
        super(inputStreamImageSource, inputStream);
        this.props = new Hashtable();
    }
    
    private static void error(String s) throws ImageFormatException {
        throw new ImageFormatException(s);
    }
    
    public boolean sendHeaderInfo(int n, int n2, boolean b, boolean b2, boolean b3) {
        this.setDimensions(n, n2);
        this.setProperties(this.props);
        if (b) {
            this.colormodel = JPEGImageDecoder.Graycolormodel;
        }
        else if (b2) {
            this.colormodel = JPEGImageDecoder.ARGBcolormodel;
        }
        else {
            this.colormodel = JPEGImageDecoder.RGBcolormodel;
        }
        this.setColorModel(this.colormodel);
        if (b3) {}
        this.setHints(22);
        this.headerComplete();
        return true;
    }
    
    public boolean sendPixels(int[] array, int n) {
        if (this.setPixels(0, n, array.length, 1, this.colormodel, array, 0, array.length) <= 0) {
            this.aborted = true;
        }
        return !this.aborted;
    }
    
    public boolean sendPixels(byte[] array, int n) {
        if (this.setPixels(0, n, array.length, 1, this.colormodel, array, 0, array.length) <= 0) {
            this.aborted = true;
        }
        return !this.aborted;
    }
    
    @Override
    public void produceImage() throws IOException, ImageFormatException {
        try {
            this.readImage(this.input, new byte[1024]);
            if (!this.aborted) {
                this.imageComplete(3, true);
            }
        }
        catch (IOException ex) {
            if (!this.aborted) {
                throw ex;
            }
            this.close();
        }
        finally {
            this.close();
        }
    }
    
    static {
        InputStreamClass = InputStream.class;
        AccessController.doPrivileged(new PrivilegedAction<Void>() {
            @Override
            public Void run() {
                System.loadLibrary("jpeg");
                return null;
            }
        });
        initIDs(JPEGImageDecoder.InputStreamClass);
        JPEGImageDecoder.RGBcolormodel = new DirectColorModel(24, 16711680, 65280, 255);
        JPEGImageDecoder.ARGBcolormodel = ColorModel.getRGBdefault();
        byte[] array = new byte[256];
        for (int i = 0; i < 256; ++i) {
            array[i] = (byte)i;
        }
        JPEGImageDecoder.Graycolormodel = new IndexColorModel(8, 256, array, array, array);
    }
}
